@@ -11,16 +11,12 @@
 
 namespace OCA\News\Command\Updater;
 
-use Exception;
-
 use OCA\News\Service\FeedServiceV2;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\OutputInterface;
 
-use OCA\News\Service\FeedService;
-
 class UpdateFeed extends Command
 {
     /**
@@ -56,13 +52,19 @@ class UpdateFeed extends Command
         $userId = $input->getArgument('user-id');
         try {
             $feed = $this->feedService->findForUser($userId, $feedId);
-            $this->feedService->fetch($feed);
-        } catch (Exception $e) {
+            $updated_feed = $this->feedService->fetch($feed);
+        } catch (\Exception $e) {
             $output->writeln(
                 '<error>Could not update feed with id ' . $feedId .
                              ' and user ' . $userId . ': ' . $e->getMessage() .
                 '</error> '
             );
+            return 1;
+        }
+
+        if ($updated_feed->getUpdateErrorCount() !== 0) {
+            $output->writeln($updated_feed->getLastUpdateError());
+            return 255;
         }
 
         return 0;
