@@ -222,11 +222,6 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this->guidHash;
     }
 
-    public function getId(): string
-    {
-        return $this->id;
-    }
-
     public function getIntro(): string
     {
         return strip_tags($this->getBody());
@@ -440,16 +435,6 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this;
     }
 
-    public function setId(int $id): self
-    {
-        if ($this->id !== $id) {
-            $this->id = $id;
-            $this->markFieldUpdated('id');
-        }
-
-        return $this;
-    }
-
     public function setLastModified(string $lastModified = null): self
     {
         if ($this->lastModified !== $lastModified) {
