@@ -52,7 +52,7 @@ class ItemMapperV2 extends NewsMapperV2
     {
         $builder = $this->db->getQueryBuilder();
         $builder->select('items.*')
-                ->from($this->tableName)
+                ->from($this->tableName, 'items')
                 ->innerJoin('items', FeedMapperV2::TABLE_NAME, 'feeds', 'items.feed_id = feeds.id')
                 ->where('feeds.user_id = :user_id')
                 ->andWhere('deleted_at = 0')
@@ -85,7 +85,7 @@ class ItemMapperV2 extends NewsMapperV2
     {
         $builder = $this->db->getQueryBuilder();
         $builder->select('items.*')
-            ->from($this->tableName)
+            ->from($this->tableName, 'items')
             ->innerJoin('items', FeedMapperV2::TABLE_NAME, 'feeds', 'items.feed_id = feeds.id')
             ->where('feeds.user_id = :user_id')
             ->andWhere('items.id = :item_id')
@@ -149,4 +149,15 @@ class ItemMapperV2 extends NewsMapperV2
 
         return $this->db->executeQuery($query)->fetch(FetchMode::ASSOCIATIVE);
     }
+
+    /**
+     * No-op clear deleted items.
+     *
+     * @param string|null $userID
+     * @param int|null    $oldestDelete
+     */
+    public function purgeDeleted(?string $userID, ?int $oldestDelete): void
+    {
+        //NO-OP
+    }
 }
