@@ -18,7 +18,7 @@ class UpdaterService
 {
 
     /**
-     * @var FolderService
+     * @var FolderServiceV2
      */
     private $folderService;
 
@@ -28,7 +28,7 @@ class UpdaterService
     private $feedService;
 
     /**
-     * @var ItemService
+     * @var ItemServiceV2
      */
     private $itemService;
 
@@ -45,8 +45,8 @@ class UpdaterService
 
     public function beforeUpdate()
     {
-        $this->folderService->purgeDeleted();
-        $this->feedService->purgeDeleted();
+        $this->folderService->purgeDeleted(null, null);
+        $this->feedService->purgeDeleted(null, null);
     }
 
 
